@@ -1,10 +1,9 @@
 from __future__ import absolute_import
 
-__version__ = "0.4.6"
+__version__ = "0.5.0"
 
 from .core.composition import *
 from .core.transforms_interface import *
 from .core.serialization import *
-from .augmentations.transforms import *
-from .augmentations.bbox_utils import *
+from .augmentations import *
 from .imgaug.transforms import *
