@@ -1,4 +1,5 @@
 import random
+from typing import Type, Dict, Tuple
 
 import cv2
 import numpy as np
@@ -62,6 +63,7 @@ from albumentations import (
     Downscale,
     MultiplicativeNoise,
     GridDropout,
+    ColorJitter,
 )
 
 
@@ -98,6 +100,7 @@ from albumentations import (
         [Downscale, {}],
         [MultiplicativeNoise, {}],
         [GridDropout, {}],
+        [ColorJitter, {}],
     ],
 )
 def test_image_only_augmentations(augmentation_cls, params, image, mask):
@@ -136,6 +139,7 @@ def test_image_only_augmentations(augmentation_cls, params, image, mask):
         [Solarize, {}],
         [MultiplicativeNoise, {}],
         [GridDropout, {}],
+        [ColorJitter, {}],
     ],
 )
 def test_image_only_augmentations_with_float_values(augmentation_cls, params, float_image, mask):
@@ -156,6 +160,7 @@ def test_image_only_augmentations_with_float_values(augmentation_cls, params, fl
         [Transpose, {}],
         [RandomRotate90, {}],
         [Rotate, {}],
+        [CoarseDropout, {"fill_value": 0, "mask_fill_value": 0}],
         [ShiftScaleRotate, {}],
         [OpticalDistortion, {}],
         [GridDistortion, {}],
@@ -278,6 +283,7 @@ def test_imgaug_dual_augmentations(augmentation_cls, image, mask):
         [Equalize, {}],
         [MultiplicativeNoise, {}],
         [GridDropout, {}],
+        [ColorJitter, {}],
     ],
 )
 def test_augmentations_wont_change_input(augmentation_cls, params, image, mask):
@@ -336,6 +342,7 @@ def test_augmentations_wont_change_input(augmentation_cls, params, image, mask):
         [Solarize, {}],
         [MultiplicativeNoise, {}],
         [GridDropout, {}],
+        [ColorJitter, {}],
     ],
 )
 def test_augmentations_wont_change_float_input(augmentation_cls, params, float_image):
@@ -378,6 +385,7 @@ def test_augmentations_wont_change_float_input(augmentation_cls, params, float_i
         [MultiplicativeNoise, {}],
         [GridDropout, {}],
         [HueSaturationValue, {}],
+        [ColorJitter, {}],
     ],
 )
 def test_augmentations_wont_change_shape_grayscale(augmentation_cls, params, image, mask):
@@ -452,6 +460,7 @@ def test_augmentations_wont_change_shape_grayscale(augmentation_cls, params, ima
         [Equalize, {}],
         [MultiplicativeNoise, {}],
         [GridDropout, {}],
+        [ColorJitter, {}],
     ],
 )
 def test_augmentations_wont_change_shape_rgb(augmentation_cls, params, image, mask):
@@ -550,3 +559,61 @@ def test_multichannel_image_augmentations_diff_channels(augmentation_cls, params
         data = aug(image=image)
         assert data["image"].dtype == np.uint8
         assert data["image"].shape[2] == num_channels
+
+
+@pytest.mark.parametrize(
+    ["augmentation_cls", "params", "image_shape"],
+    [
+        [PadIfNeeded, {"min_height": 514, "min_width": 516}, (300, 200)],
+        [PadIfNeeded, {"min_height": 514, "min_width": 516}, (512, 516)],
+        [PadIfNeeded, {"min_height": 514, "min_width": 516}, (600, 600)],
+        [
+            PadIfNeeded,
+            {"min_height": None, "min_width": None, "pad_height_divisor": 128, "pad_width_divisor": 128},
+            (300, 200),
+        ],
+        [
+            PadIfNeeded,
+            {"min_height": None, "min_width": None, "pad_height_divisor": 72, "pad_width_divisor": 128},
+            (72, 128),
+        ],
+        [
+            PadIfNeeded,
+            {"min_height": None, "min_width": None, "pad_height_divisor": 72, "pad_width_divisor": 128},
+            (15, 15),
+        ],
+        [
+            PadIfNeeded,
+            {"min_height": None, "min_width": None, "pad_height_divisor": 72, "pad_width_divisor": 128},
+            (144, 256),
+        ],
+        [
+            PadIfNeeded,
+            {"min_height": None, "min_width": None, "pad_height_divisor": 72, "pad_width_divisor": 128},
+            (200, 300),
+        ],
+        [PadIfNeeded, {"min_height": 512, "min_width": None, "pad_width_divisor": 128}, (300, 200)],
+        [PadIfNeeded, {"min_height": None, "min_width": 512, "pad_height_divisor": 128}, (300, 200)],
+    ],
+)
+def test_pad_if_needed(augmentation_cls: Type[PadIfNeeded], params: Dict, image_shape: Tuple[int, int]):
+    image = np.zeros(image_shape)
+    pad = augmentation_cls(**params)
+
+    image_padded = pad(image=image)["image"]
+
+    if pad.min_width is not None:
+        assert image_padded.shape[1] >= pad.min_width
+
+    if pad.min_height is not None:
+        assert image_padded.shape[0] >= pad.min_height
+
+    if pad.pad_width_divisor is not None:
+        assert image_padded.shape[1] % pad.pad_width_divisor == 0
+        assert image_padded.shape[1] >= image.shape[1]
+        assert image_padded.shape[1] - image.shape[1] <= pad.pad_width_divisor
+
+    if pad.pad_height_divisor is not None:
+        assert image_padded.shape[0] % pad.pad_height_divisor == 0
+        assert image_padded.shape[0] >= image.shape[0]
+        assert image_padded.shape[0] - image.shape[0] <= pad.pad_height_divisor
